#------------------------------------------------------------------------------
# Copyright (c) 2008, Enthought, Inc.
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in enthought/LICENSE.txt and may be redistributed only
# under the conditions described in the aforementioned license.  The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
# Thanks for using Enthought open source!
#
# Author: Ilan Schnell, Enthought, Inc.
#
# Description:
#     Unittest to run another (unittest) script directly.
#     In some cases this is necessary when things cannot be tested
#     with nosetests itself.
#------------------------------------------------------------------------------
import os
import subprocess
import unittest

# NOTE:
#   `check_version_registry.py` can not be run by nosetests directly because of
#   namespace issues.   Therefore the test in this file (which nosetests
#   will execute) will spawn a python interpreter running the unittest.
#   This test checks the return code of the process and will fail if
#   the return code is non-zero.

class RefreshTestCase(unittest.TestCase):

    def test_run(self):
        cwd = os.path.dirname(__file__)
        if not cwd:
            cwd = '.'

        retcode = subprocess.call(['python', 'check_version_registry.py'],
                                  cwd=cwd)

        self.assertEqual(retcode, 0)


if __name__ == "__main__":
    unittest.main()



from i_preferences import IPreferences

from package_globals import get_default_preferences, set_default_preferences
from preferences import Preferences
from preference_binding import PreferenceBinding, bind_preference
from preferences_helper import PreferencesHelper
from scoped_preferences import ScopedPreferences



#------------------------------------------------------------------------------
# Copyright (c) 2008, Enthought, Inc.
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in enthought/LICENSE.txt and may be redistributed only
# under the conditions described in the aforementioned license.  The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
# Thanks for using Enthought open source!
#
# Author: Ilan Schnell, Enthought, Inc.
#
# Description:
#     Unittest to run another script directly.  In some cases this is
#     necessary when things cannot be tested with nosetests itself.
#------------------------------------------------------------------------------
import sys
import os.path
import subprocess
import unittest
import tempfile

from traits.util.resource import store_resource, get_path


class Tests(unittest.TestCase):

    def setUp(self):
        OS_handle, fname = tempfile.mkstemp()
        os.close(OS_handle)
        self.tmpname = fname


    def test_file_path(self):
        """
            Run 'check_file_path.py' as a spawned process and test
            return value,
            The python source is stored into a temporary test file before
            being executed in a subprocess.
        """
        store_resource('AppTools',
                       os.path.join('apptools', 'persistence','tests',
                                    'check_file_path.py'),
                       self.tmpname)

        retcode = subprocess.call([sys.executable, self.tmpname],
                                  cwd=get_path(Tests))

        self.assertEqual(retcode, 0)


    def test_version_registry(self):
        """
            Run 'check_version_registry.py' as a spawned process and test
            return value,
            The python source is stored into a temporary test file before
            being executed in a subprocess.
        """
        store_resource('AppTools',
                       os.path.join('apptools', 'persistence','tests',
                                    'check_version_registry.py'),
                       self.tmpname)

        retcode = subprocess.call([sys.executable, self.tmpname])

        self.assertEqual(retcode, 0)


    def tearDown(self):
        os.unlink(self.tmpname)

if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2008-2012 by Enthought, Inc.
# All rights reserved.
from os.path import join
from setuptools import setup, find_packages


info = {}
execfile(join('apptools', '__init__.py'), info)


setup(
    name = 'apptools',
    version = info['__version__'],
    author = 'Enthought, Inc.',
    author_email = 'info@enthought.com',
    maintainer = 'ETS Developers',
    maintainer_email = 'enthought-dev@enthought.com',
    url = 'https://github.com/enthought/apptools',
    download_url = ('http://www.enthought.com/repo/ets/apptools-%s.tar.gz' %
                    info['__version__']),
    classifiers = [c.strip() for c in """\
        Development Status :: 5 - Production/Stable
        Intended Audience :: Developers
        Intended Audience :: Science/Research
        License :: OSI Approved :: BSD License
        Operating System :: MacOS
        Operating System :: Microsoft :: Windows
        Operating System :: OS Independent
        Operating System :: POSIX
        Operating System :: Unix
        Programming Language :: Python
        Topic :: Scientific/Engineering
        Topic :: Software Development
        Topic :: Software Development :: Libraries
        """.splitlines() if len(c.strip()) > 0],
    description = 'application tools',
    long_description = open('README.rst').read(),
    include_package_data = True,
    package_data = dict(apptools=[
            'help/help_plugin/*.ini',
            'logger/plugin/*.ini',
            'naming/ui/images/*.png',
            'help/help_plugin/action/images/*.png',
    ]),
    install_requires = info['__requires__'],
    license = 'BSD',
    packages = find_packages(),
    platforms = ["Windows", "Linux", "Mac OS-X", "Unix", "Solaris"],
    zip_safe = False,
)
